import type { DynamicZodModelClass, GraphQLMDF } from './types';
import type { WrapWithZodOptions } from './zod-options-wrapper.interface';
import type { TypeProvider } from '../types/type-provider';
import type { EnumProvider } from '../types/enum-provider';
import type { AnyZodObject } from 'zod';
import type { BaseTypeOptions } from '@nestjs/graphql';
type BaseOptions<T extends AnyZodObject> = WrapWithZodOptions<BaseTypeOptions, T>;
/**
 * Returns a method decorator that is built with `zod` validation object.
 *
 * @export
 * @template T The type of the `zod` validation object.
 * @param {T} input The `zod` validation object.
 * @param {(string | BaseOptions<T> | undefined)} nameOrOptions The name or
 * the options.
 *
 * @param {GraphQLMDF<BaseTypeOptions>} graphqlDecoratorFactory The actual
 * decorator factory function.
 *
 * @param {DynamicZodModelClass<T>} model The dynamically built model class from
 * `zod` validation object.
 *
 * @return {MethodDecorator} A method decorator.
 */
export declare function MethodWithZodModel<T extends AnyZodObject>(input: T, nameOrOptions: string | BaseOptions<T> | undefined, graphqlDecoratorFactory: GraphQLMDF<BaseTypeOptions>, model: DynamicZodModelClass<T>): MethodDecorator;
/**
 * Returns a method decorator that is built with `zod` validation object.
 *
 * @export
 * @template T The type of the `zod` validation object.
 * @param {T} input The `zod` validation object.
 * @param {(string | BaseOptions<T> | undefined)} nameOrOptions The name or
 * the options.
 *
 * @param {GraphQLMDF<BaseTypeOptions>} graphqlDecoratorFactory The actual
 * decorator factory function.
 *
 * @return {MethodDecorator} A method decorator.
 */
export declare function MethodWithZod<T extends AnyZodObject>(input: T, nameOrOptions: string | BaseOptions<T> | undefined, graphqlDecoratorFactory: GraphQLMDF<BaseTypeOptions>): MethodDecorator;
/**
 * Sets the default type provider for custom GraphQL Scalars.
 *
 * The type name will be calculated and it will be similar to `TypeScript`
 * types such as: `Record<Optional<String>, Array<Number | String>>`.
 *
 * The user will provide custom scalar type to use for that kind of
 * zod validation.
 *
 * @export
 * @param {TypeProvider} fn The type provider.
 */
export declare function setDefaultTypeProvider(fn: TypeProvider): void;
/**
 * Gets the default type provided set previously
 * via {@link setDefaultTypeProvider}.
 *
 * @export
 * @return {TypeProvider | undefined} The default type provider.
 */
export declare function getDefaultTypeProvider(): TypeProvider | undefined;
/**
 * Sets the default enum provider for custom GraphQL Scalars.
 *
 * @export
 * @param {EnumProvider} fn The enum provider.
 */
export declare function setDefaultEnumProvider(fn: EnumProvider): void;
/**
 * Gets the default enum provided set previously
 * via {@link setDefaultEnumProvider}.
 *
 * @export
 * @return {EnumProvider | undefined} The default enum provider.
 */
export declare function getDefaultEnumProvider(): EnumProvider | undefined;
export {};
