import { InputTypeOptions } from '@nestjs/graphql';
import type { AnyZodObject } from 'zod';
import type { Options } from './options.inteface';
/**
 * Decorator that marks a class as a GraphQL input type.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @return {ClassDecorator} A {@link ClassDecorator}.
 */
export declare function InputTypeWithZod<T extends AnyZodObject>(input: T): ClassDecorator;
/**
 * Decorator that marks a class as a GraphQL input type.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @param {Options<T>} options The options for the decorator.
 * @return {ClassDecorator} A {@link ClassDecorator}.
 */
export declare function InputTypeWithZod<T extends AnyZodObject>(input: T, options: Options<T>): ClassDecorator;
/**
 * Decorator that marks a class as a GraphQL input type.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @param {string} name The name of the {@link InputType}.
 * @param {Options<T>} [options] The options for the decorator.
 * @return {ClassDecorator} A {@link ClassDecorator}.
 */
export declare function InputTypeWithZod<T extends AnyZodObject>(input: T, name: string, options?: Options<T>): ClassDecorator;
/**
 * Builds an input type decorator for given name and options.
 *
 * @param {string} [name] The name of the property.
 * @param {InputTypeOptions} [opts] The options for the decorator.
 * @return {ClassDecorator} A decorator for the dynamic input type class.
 */
export declare function buildInputTypeDecorator(name?: string, opts?: InputTypeOptions): ClassDecorator;
