"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildInputTypeDecorator = exports.InputTypeWithZod = void 0;
const graphql_1 = require("@nestjs/graphql");
const helpers_1 = require("../../helpers");
const constants_1 = require("../../helpers/constants");
function InputTypeWithZod(input, nameOrOptions, options) {
    //#region Parameter Normalization - `name`, `zodOptions`, `inputTypeOptions`
    if (typeof nameOrOptions === 'object') {
        options = nameOrOptions;
        nameOrOptions = undefined;
    }
    if (!nameOrOptions) {
        nameOrOptions = options === null || options === void 0 ? void 0 : options.name;
    }
    const name = nameOrOptions;
    let zodOptions = options === null || options === void 0 ? void 0 : options.zod;
    let inputTypeOptions;
    if (typeof options === 'object') {
        const { name: _, zod: __ } = options, rest = __rest(options, ["name", "zod"]);
        inputTypeOptions = rest;
    }
    //#endregion
    const decorate = buildInputTypeDecorator(name, inputTypeOptions);
    return function ZodClassDecoratorBase(target) {
        zodOptions !== null && zodOptions !== void 0 ? zodOptions : (zodOptions = {});
        const { prototype } = target;
        const { description, name = target.name } = (0, helpers_1.extractNameAndDescription)(input, zodOptions);
        const { keepZodObject = false } = zodOptions;
        const returnValue = decorate(target);
        if (keepZodObject) {
            Object.defineProperty(prototype, constants_1.ZodObjectKey, {
                value: Object.assign({}, input),
                configurable: false,
                writable: false
            });
        }
        const parsed = (0, helpers_1.parseShape)(input, Object.assign(Object.assign({}, zodOptions), { name,
            description,
            getDecorator(_, key) {
                // Returning another `@InputType()` as we have another key now, that
                // will be another sub class built, therefore we need to decorate that
                // with another `@InputType()`.
                return buildInputTypeDecorator(key, inputTypeOptions);
            }, getScalarTypeFor: zodOptions.getScalarTypeFor }));
        for (const { descriptor, key, decorateFieldProperty } of parsed) {
            Object.defineProperty(prototype, key, descriptor);
            decorateFieldProperty(prototype, key);
        }
        return returnValue;
    };
}
exports.InputTypeWithZod = InputTypeWithZod;
/**
 * Builds an input type decorator for given name and options.
 *
 * @param {string} [name] The name of the property.
 * @param {InputTypeOptions} [opts] The options for the decorator.
 * @return {ClassDecorator} A decorator for the dynamic input type class.
 */
function buildInputTypeDecorator(name, opts) {
    if (typeof opts === 'object') {
        if (typeof name === 'string') {
            return (0, graphql_1.InputType)(name, opts);
        }
        return (0, graphql_1.InputType)(opts);
    }
    if (typeof name === 'string') {
        return (0, graphql_1.InputType)(name);
    }
    return (0, graphql_1.InputType)();
}
exports.buildInputTypeDecorator = buildInputTypeDecorator;
//# sourceMappingURL=input-type-with-zod.js.map