"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeDecoratorFromFactory = void 0;
/**
 * Builds a decorator from a decorator factory function.
 *
 * @export
 * @template T The type of the `zod` validation object.
 * @template O The type of the supported option type.
 * @param {(WrapWithZodOptions<O, T> | string | undefined)} nameOrOptions The
 * name or the options.
 *
 * @param {(GraphQLMDF<O> | GraphQLCDF<O>)} decoratorFactory The decorator
 * factory.
 *
 * @param {DynamicZodModelClass<T>} model The class that is dynamically built.
 *
 * @return {MethodDecorator | ClassDecorator | ParameterDecorator} A decorator.
 */
function makeDecoratorFromFactory(nameOrOptions, decoratorFactory, model) {
    let decorator;
    if (typeof nameOrOptions === 'string') {
        const factory = decoratorFactory;
        decorator = factory(nameOrOptions);
    }
    else if (typeof nameOrOptions === 'object') {
        const { zod } = nameOrOptions, rest = __rest(nameOrOptions, ["zod"]);
        const factory = decoratorFactory;
        decorator = factory(() => model, rest);
    }
    else {
        const factory = decoratorFactory;
        decorator = factory(() => model);
    }
    return decorator;
}
exports.makeDecoratorFromFactory = makeDecoratorFromFactory;
//# sourceMappingURL=make-decorator-from-factory.js.map