import { SubscriptionOptions as SO } from '@nestjs/graphql';
import { IModelFromZodOptions } from '../../model-from-zod';
import type { AnyZodObject } from 'zod';
export interface SubscriptionOptions<T extends AnyZodObject> extends SO {
    /**
     * Options for model creation from `zod`.
     *
     * @type {IModelFromZodOptions<T>}
     * @memberof QueryOptions
     */
    zod?: IModelFromZodOptions<T>;
}
/**
 * Subscription handler (method) Decorator.
 * Routes subscriptions to this method.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @return {MethodDecorator} A {@link MethodDecorator}.
 */
export declare function SubscriptionWithZod<T extends AnyZodObject>(input: T): MethodDecorator;
/**
 * Subscription handler (method) Decorator.
 * Routes subscriptions to this method.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @param {string} name The name of the method.
 * @return {MethodDecorator} A {@link MethodDecorator}.
 */
export declare function SubscriptionWithZod<T extends AnyZodObject>(input: T, name: string): MethodDecorator;
/**
 * Subscription handler (method) Decorator.
 * Routes subscriptions to this method.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @param {SubscriptionOptions<zod.infer<T>>} options The options for
 * subscription method.
 *
 * @return {MethodDecorator} A {@link MethodDecorator}.
 */
export declare function SubscriptionWithZod<T extends AnyZodObject>(input: T, options: SubscriptionOptions<T>): MethodDecorator;
/**
 * Subscription handler (method) Decorator.
 * Routes subscriptions to this method.
 *
 * Uses a `zod` object.
 *
 * @export
 * @template T The type of the zod object input.
 * @param {T} input The zod input object.
 * @param {string} name The name of the method.
 * @param {SubscriptionOptions<zod.infer<T>>} options The options for
 * subscription method.
 *
 * @return {MethodDecorator} A {@link MethodDecorator}.
 */
export declare function SubscriptionWithZod<T extends AnyZodObject>(input: T, name: string, options: Pick<SubscriptionOptions<T>, 'filter' | 'resolve' | 'zod'>): MethodDecorator;
