import { infer as Infer, ZodType, ZodTypeAny } from 'zod';
import type { IModelFromZodOptions } from '../model-from-zod';
/**
 * Creates a property descriptor that provides `get` and `set` functions
 * that are using `parse` or `safeParse` methods of the `zod` library.
 *
 * @export
 * @template T The type of the target object.
 * @param {keyof T} key The key of the property that is being created.
 * @param {zod.ZodTypeAny} input The zod object input.
 * @param {IModelFromZodOptions<T>} opts The options.
 * @return {PropertyDescriptor} A {@link PropertyDescriptor}.
 */
export declare function createZodPropertyDescriptor<T extends ZodType>(key: keyof Infer<T>, input: ZodTypeAny, opts: IModelFromZodOptions<T>): PropertyDescriptor;
