"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractNameAndDescription = void 0;
const constants_1 = require("./constants");
const get_description_1 = require("./get-description");
/**
 * Extracts the name and description from a zod object input.
 *
 * @export
 * @template T The zod object input type.
 * @param {T} zodInput The zod object input.
 * @param {IModelFromZodOptions<T>} options The options for the operation.
 * @return {{ name: string, description: string }} An object containing
 * normalized name and description info.
 */
function extractNameAndDescription(zodInput, options) {
    let { name } = options;
    let description = (0, get_description_1.getDescription)(zodInput);
    if (!name) {
        if (description) {
            const match = description.match(/(\w+):\s*?(.*)+/);
            if (match) {
                const [_full, className, actualDescription] = match;
                name = className;
                description = actualDescription.trim();
                return { name, description };
            }
        }
        name = `ClassFromZod_${(0, constants_1.getAndIncreaseRegisterCount)()}`;
    }
    return { name, description };
}
exports.extractNameAndDescription = extractNameAndDescription;
//# sourceMappingURL=extract-name-and-description.js.map