"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDefaults = void 0;
const zod_1 = require("zod");
const is_zod_instance_1 = require("./is-zod-instance");
/**
 * Generates the default values for given object.
 *
 * This function is recursive with {@link generateDefaults}.
 *
 * @param {AnyZodObject} input The input.
 * @return {Record<string, ZodTypeAny>} A record of default values.
 */
function generateDefaultsForObject(input) {
    return Object.keys(input.shape).reduce((curr, key) => {
        const res = generateDefaults(input.shape[key]);
        if (res) {
            curr[key] = res;
        }
        return curr;
    }, {});
}
/**
 * Generates the default vales for given input.
 *
 * @export
 * @template T The type of the input.
 * @param {T} input The input.
 * @return {*} A record containing keys and the zod
 * values with defaults.
 */
function generateDefaults(input) {
    var _a, _b;
    if ((0, is_zod_instance_1.isZodInstance)(zod_1.ZodObject, input)) {
        return generateDefaultsForObject(input);
    }
    else if ((0, is_zod_instance_1.isZodInstance)(zod_1.ZodDefault, input)) {
        return (_b = (_a = input._def).defaultValue) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
}
exports.generateDefaults = generateDefaults;
//# sourceMappingURL=generate-defaults.js.map