"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withSuffix = void 0;
/**
 * Returns a function which will take a string and return another string
 * with the given suffix, if the suffix was already there then this function
 * will simply return the string value.
 *
 * @export
 * @typedef S The suffix string.
 * @param {S} suffix The suffix string.
 * @return {(input: string) => string} The suffixed string.
 */
function withSuffix(suffix) {
    /**
     * Returns a string with previously entered suffix is applied.
     * @typedef I The input string.
     * @param {I} input The input string.
     * @return {Suffixed<S, I>} The suffixed string.
     */
    return function _withSuffix(input) {
        if (input.endsWith(suffix)) {
            return input;
        }
        return (input + suffix);
    };
}
exports.withSuffix = withSuffix;
//# sourceMappingURL=with-suffix.js.map