"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZodValidatorPipe = void 0;
const common_1 = require("@nestjs/common");
/**
 * A validation pipe from `zod` validation schema.
 *
 * @export
 * @class ZodValidatorPipe
 * @implements {PipeTransform}
 * @template T The type of the `zod` validation schema.
 */
class ZodValidatorPipe {
    constructor(input, klass) {
        this.input = input;
        this.klass = klass;
    }
    async transform(value, _metadata) {
        try {
            return await this.input.parseAsync(value, { async: true });
        }
        catch (error_) {
            const error = error_;
            const message = error.issues.map(issue => {
                const property = issue.path[0];
                const targetValue = issue.path.reduce((prev, curr) => {
                    if (!prev)
                        return;
                    if (typeof prev !== 'object')
                        return;
                    return prev[curr];
                }, value);
                let children;
                if (issue.path.length > 1) {
                    children = [{ property: String(issue.path[1]) }];
                    let curr = children[0];
                    for (let i = 2, limit = issue.path.length; i < limit; ++i) {
                        curr.children = [curr = { property: String(issue.path[i]) }];
                    }
                    curr.value = targetValue;
                    curr.constraints = {
                        [issue.code]: issue.message
                    };
                }
                return {
                    property,
                    children,
                    value: targetValue,
                    constraints: {
                        [issue.code]: issue.message
                    },
                };
            });
            throw new common_1.BadRequestException(message, 'Validation Exception');
        }
    }
}
exports.ZodValidatorPipe = ZodValidatorPipe;
//# sourceMappingURL=zod-validator.pipe.js.map